import {ICellRendererAngularComp} from 'ag-grid-angular';
import {Component, HostListener} from '@angular/core';
import {ICellRendererParams} from 'ag-grid-community';
import {NavigationService} from '../../../../service/navigation.service';

@Component({
    selector: 'editor-page-link-renderer',
    template: `
    <div title="Control-click to open this page" (click)="onClick($event)" *ngIf="pageId">
        <i class="fa fa-sticky-note" style="margin-right: 5px; color: var(--noded-background-note);"></i> {{ pageTitle }}
    </div>`,
})
export class PageLinkRendererComponent implements ICellRendererAngularComp {
    public params: ICellRendererParams;
    public pageId?: string;
    public pageTitle?: string;

    constructor(
        protected readonly nav: NavigationService,
    ) { }

    agInit(params: ICellRendererParams): void {
        this.params = params;
        this.pageId = params.value;

        // @ts-ignore
        const page = params._pagesData.find(x => x.id === this.pageId);
        if ( page ) {
            this.pageTitle = page.name;
        }
    }

    // @HostListener('click', ['@event.target'])
    onClick(event) {
        if ( event.ctrlKey ) {
            event.stopPropagation();
            event.preventDefault();
            this.nav.requestNavigation(this.pageId);
        }
    }

    refresh(params: any): boolean {
        return false;
    }
}
